#!/bin/bash
# Create Wimlib ntfs-3g for the program Windows Install
# By Sergey_Galan
#❗️Make sure you have Apple Command Line Tools or Xcode installed
#❗️There must be links to current releases

downloadsConfig=https://pkgconfig.freedesktop.org/releases/pkg-config-0.29.2.tar.gz
#downloadsConfig=https://download.gnome.org/sources/glib/2.9/glib-2.9.6.tar.gz
downloadsNTFS=https://tuxera.com/opensource/ntfs-3g_ntfsprogs-2022.10.3.tgz
downloadsWimlib=https://wimlib.net/downloads/wimlib-1.14.4.tar.gz

configVer="${downloadsConfig##*/}"
ntfs3gVer="${downloadsNTFS##*/}"
wimlibVer="${downloadsWimlib##*/}"
configPak="$HOME/Downloads/$configVer"
ntfs3gPak="$HOME/Downloads/$ntfs3gVer"
wimlibPak="$HOME/Downloads/$wimlibVer"
configDir="${configPak%.*.*}"
ntfs3gDir="${ntfs3gPak%.*}"
wimlibDir="${wimlibPak%.*.*}"
 if [[ -e "$configDir" ]] && [[ -e "$ntfs3gDir" ]] && [[ -e "$wimlibDir" ]]; then
    echo "Resource found"
else
    echo "Download"
    echo $configPak
    echo $ntfs3gPak
    echo $wimlibPak
    curl -C - -L "$downloadsConfig" > "$configPak"
    curl -C - -L "$downloadsNTFS" > "$ntfs3gPak"
    curl -C - -L "$downloadsWimlib" > "$wimlibPak"
    echo "Unpacking"
    echo $configDir
    echo $ntfs3gDir
    echo $wimlibDir
    tar -xf "$configPak" --directory "$HOME/Downloads" 2>/dev/null
    tar -xf "$ntfs3gPak" --directory "$HOME/Downloads" 2>/dev/null
    tar -xf "$wimlibPak" --directory "$HOME/Downloads" 2>/dev/null
fi

 if [[ -e "$configDir" ]] && [[ -e "$ntfs3gDir" ]] && [[ -e "$wimlibDir" ]]; then
    echo "OK"
else
    echo "Failed to unpack"
    echo "Cancel"
    exit
fi

 echo "Please enter your password"
if [[ ! -d "$(xcode-select -p)" ]]; then
    sudo xcode-select --install
fi

if [[ -e /usr/local/lib ]]; then
   sudo cp -Rp "/usr/local" "$HOME"
fi

echo " "
echo "##########"
echo "Install pkg-config"
cd "$configDir"
Sleep 1
# Work-around for build issue with Xcode 15.3
# https://gitlab.freedesktop.org/pkg-config/pkg-config/-/issues/81
export CFLAGS="-Wno-int-conversion"
export CXXFLAGS="-Wno-int-conversion"
./configure --disable-debug --prefix=/usr/local --mandir=/usr/local/share/man --bindir=/usr/local/bin --disable-host-tool --with-internal-glib
make
sudo make install
   
echo " "
echo "##########"
echo "Install ntfs-3g"
cd "$ntfs3gDir"
Sleep 1
./configure --disable-mtab --disable-plugins --disable-ntfs-3g --disable-debug --disable-dependency-tracking --prefix=/usr/local --exec-prefix=/usr/local --sbindir=/usr/local/sbin --libdir=/usr/local/lib --includedir=/usr/local/include
make
sudo make install

echo " "
echo "##########"
echo "Install wimlib"
cd "$wimlibDir"
Sleep 1
./configure --without-fuse --prefix=/usr/local
make
sudo make install

echo "Path libwim.15.dylib"
sudo install_name_tool -id @executable_path/../lib/libwim.15.dylib /usr/local/lib/libwim.15.dylib
sudo install_name_tool -change /usr/local/lib/libntfs-3g.89.dylib @executable_path/../lib/libntfs-3g.89.dylib /usr/local/lib/libwim.15.dylib
sudo install_name_tool -change /usr/local/opt/gettext/lib/libintl.8.dylib @executable_path/../lib/libintl.8.dylib /usr/local/lib/libwim.15.dylib

echo "Path libntfs-3g.89.dylib"
sudo install_name_tool -id @executable_path/../lib/libntfs-3g.89.dylib /usr/local/lib/libntfs-3g.89.dylib
sudo install_name_tool -change /usr/local/opt/gettext/lib/libintl.8.dylib @executable_path/../lib/libintl.8.dylib /usr/local/lib/libntfs-3g.89.dylib

echo "Path wimlib-imagex"
sudo install_name_tool -change /usr/local/lib/libwim.15.dylib @executable_path/../lib/libwim.15.dylib /usr/local/bin/wimlib-imagex
sudo install_name_tool -change /usr/local/lib/libntfs-3g.89.dylib @executable_path/../lib/libntfs-3g.89.dylib /usr/local/bin/wimlib-imagex
sudo install_name_tool -change /usr/local/opt/gettext/lib/libintl.8.dylib @executable_path/../lib/libintl.8.dylib /usr/local/bin/wimlib-imagex

echo "Path mkntfs"
sudo install_name_tool -change /usr/local/lib/libntfs-3g.89.dylib @executable_path/../lib/libntfs-3g.89.dylib /usr/local/sbin/mkntfs
sudo install_name_tool -change /usr/local/opt/gettext/lib/libintl.8.dylib @executable_path/../lib/libintl.8.dylib /usr/local/sbin/mkntfs

mkdir "$HOME/Desktop/tools/"
mkdir "$HOME/Desktop/tools/lib/"
mkdir "$HOME/Desktop/tools/bin/"
sudo mv /usr/local/lib/libwim.15.dylib "$HOME/Desktop/tools/lib/libwim.15.dylib"
sudo mv /usr/local/lib/libntfs-3g.89.dylib "$HOME/Desktop/tools/lib/libntfs-3g.89.dylib"
sudo mv /usr/local/bin/wimlib-imagex "$HOME/Desktop/tools/bin/wimlib-imagex"
sudo mv /usr/local/sbin/mkntfs "$HOME/Desktop/tools/bin/mkntfs"

sudo rm -rf /usr/local/* 2>/dev/null
cp -Rp "$HOME/local/" "/usr/local/" 2>/dev/null
rm -rf "$HOME/local" 2>/dev/null
echo

echo "Signature"
sudo codesign --verbose --force -s - "$HOME/Desktop/tools/lib/libwim.15.dylib"
sudo codesign --verbose --force -s - "$HOME/Desktop/tools/lib/libntfs-3g.89.dylib"
sudo codesign --verbose --force -s - "$HOME/Desktop/tools/bin/wimlib-imagex"
sudo codesign --verbose --force -s - "$HOME/Desktop/tools/bin/mkntfs"
echo

echo "Signature verification"
codesign --display --verbose "$HOME/Desktop/tools/lib/libwim.15.dylib"
codesign --display --verbose "$HOME/Desktop/tools/lib/libntfs-3g.89.dylib"
codesign --display --verbose "$HOME/Desktop/tools/bin/wimlib-imagex"
codesign --display --verbose "$HOME/Desktop/tools/bin/mkntfs"
echo

echo "Permissions"
ls -l "$HOME/Desktop/tools/"*
open "$HOME/Desktop/tools/"
exit